﻿# Prerequisites - Install the SPO management shell from https://www.microsoft.com/en-us/download/details.aspx?id=35588

$dllpath = [environment]::getfolderpath("programfiles") + "\SharePoint Online Management Shell\Microsoft.Online.SharePoint.PowerShell\Microsoft.SharePoint.Client.dll";

if(([System.IO.File]::Exists($dllpath)) -eq $false)
{
	Write-Host -ForegroundColor Red 'Install the SPO management shell from https://www.microsoft.com/en-us/download/details.aspx?id=35588';
	exit;
}

add-type -Path $dllpath

Write-Host 'Enter Muhimbi SPFx path and App Catalog URL'
 
$apppath = Read-Host 'Muhimbi SPFx file path'
$siteurl = Read-Host 'App catalog site URL (where app is going to be installed)'

if($apppath -eq '' -or $siteurl -eq '')
{
	Write-Host -ForegroundColor Red 'All parameters are required, please try again.';
	exit;
}

Connect-PnPOnline -Url $siteurl -UseWebLogin
try
{
    $appCatalgUrl = Get-PnPTenantAppCatalogUrl
    if ($appCatalgUrl -eq '')
    {
        Write-Host -ForegroundColor Red 'Please create app catalog in your tenant';
        exit;
    }
    Write-Host 'Uploading SPFx package in app catalog';
    $spfx = Add-PnPApp -Path $apppath -Scope Tenant 

    if (!$spfx.Deployed)
    {
        Write-Host 'Deploying SPFx package across tenant';
        Publish-PnPApp -Identity $spfx.Id -SkipFeatureDeployment -Scope Tenant
    }
    Write-Host -ForegroundColor Green 'Operation completed successfully. Please check your site';
}
catch
{
    Write-Host -ForegroundColor Red 'Error encountered while executing script: ' + $Error[0].ToString();
}